# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsConfig(Model):
    """Models config (models.Config)

    Properties:
        chat_rate_limit_burst: (ChatRateLimitBurst) REQUIRED int

        chat_rate_limit_duration: (ChatRateLimitDuration) REQUIRED int

        concurrent_users_limit: (ConcurrentUsersLimit) REQUIRED int

        enable_profanity_filter: (EnableProfanityFilter) REQUIRED bool

        filter_app_name: (FilterAppName) REQUIRED str

        filter_param: (FilterParam) REQUIRED str

        filter_type: (FilterType) REQUIRED str

        general_rate_limit_burst: (GeneralRateLimitBurst) REQUIRED int

        general_rate_limit_duration: (GeneralRateLimitDuration) REQUIRED int

        namespace: (Namespace) REQUIRED str

        shard_capacity_limit: (ShardCapacityLimit) REQUIRED int

        shard_default_limit: (ShardDefaultLimit) REQUIRED int

        shard_hard_limit: (ShardHardLimit) REQUIRED int

        spam_chat_burst: (SpamChatBurst) REQUIRED int

        spam_chat_duration: (SpamChatDuration) REQUIRED int

        spam_mute_duration: (SpamMuteDuration) REQUIRED int

        default_dictionary_loaded: (defaultDictionaryLoaded) OPTIONAL bool

        enable_clan_chat: (enableClanChat) OPTIONAL bool

        enable_manual_topic_creation: (EnableManualTopicCreation) OPTIONAL bool

        max_chat_message_length: (maxChatMessageLength) OPTIONAL int

        use_default_dictionary: (useDefaultDictionary) OPTIONAL bool
    """

    # region fields

    chat_rate_limit_burst: int  # REQUIRED
    chat_rate_limit_duration: int  # REQUIRED
    concurrent_users_limit: int  # REQUIRED
    enable_profanity_filter: bool  # REQUIRED
    filter_app_name: str  # REQUIRED
    filter_param: str  # REQUIRED
    filter_type: str  # REQUIRED
    general_rate_limit_burst: int  # REQUIRED
    general_rate_limit_duration: int  # REQUIRED
    namespace: str  # REQUIRED
    shard_capacity_limit: int  # REQUIRED
    shard_default_limit: int  # REQUIRED
    shard_hard_limit: int  # REQUIRED
    spam_chat_burst: int  # REQUIRED
    spam_chat_duration: int  # REQUIRED
    spam_mute_duration: int  # REQUIRED
    default_dictionary_loaded: bool  # OPTIONAL
    enable_clan_chat: bool  # OPTIONAL
    enable_manual_topic_creation: bool  # OPTIONAL
    max_chat_message_length: int  # OPTIONAL
    use_default_dictionary: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_chat_rate_limit_burst(self, value: int) -> ModelsConfig:
        self.chat_rate_limit_burst = value
        return self

    def with_chat_rate_limit_duration(self, value: int) -> ModelsConfig:
        self.chat_rate_limit_duration = value
        return self

    def with_concurrent_users_limit(self, value: int) -> ModelsConfig:
        self.concurrent_users_limit = value
        return self

    def with_enable_profanity_filter(self, value: bool) -> ModelsConfig:
        self.enable_profanity_filter = value
        return self

    def with_filter_app_name(self, value: str) -> ModelsConfig:
        self.filter_app_name = value
        return self

    def with_filter_param(self, value: str) -> ModelsConfig:
        self.filter_param = value
        return self

    def with_filter_type(self, value: str) -> ModelsConfig:
        self.filter_type = value
        return self

    def with_general_rate_limit_burst(self, value: int) -> ModelsConfig:
        self.general_rate_limit_burst = value
        return self

    def with_general_rate_limit_duration(self, value: int) -> ModelsConfig:
        self.general_rate_limit_duration = value
        return self

    def with_namespace(self, value: str) -> ModelsConfig:
        self.namespace = value
        return self

    def with_shard_capacity_limit(self, value: int) -> ModelsConfig:
        self.shard_capacity_limit = value
        return self

    def with_shard_default_limit(self, value: int) -> ModelsConfig:
        self.shard_default_limit = value
        return self

    def with_shard_hard_limit(self, value: int) -> ModelsConfig:
        self.shard_hard_limit = value
        return self

    def with_spam_chat_burst(self, value: int) -> ModelsConfig:
        self.spam_chat_burst = value
        return self

    def with_spam_chat_duration(self, value: int) -> ModelsConfig:
        self.spam_chat_duration = value
        return self

    def with_spam_mute_duration(self, value: int) -> ModelsConfig:
        self.spam_mute_duration = value
        return self

    def with_default_dictionary_loaded(self, value: bool) -> ModelsConfig:
        self.default_dictionary_loaded = value
        return self

    def with_enable_clan_chat(self, value: bool) -> ModelsConfig:
        self.enable_clan_chat = value
        return self

    def with_enable_manual_topic_creation(self, value: bool) -> ModelsConfig:
        self.enable_manual_topic_creation = value
        return self

    def with_max_chat_message_length(self, value: int) -> ModelsConfig:
        self.max_chat_message_length = value
        return self

    def with_use_default_dictionary(self, value: bool) -> ModelsConfig:
        self.use_default_dictionary = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "chat_rate_limit_burst"):
            result["ChatRateLimitBurst"] = int(self.chat_rate_limit_burst)
        elif include_empty:
            result["ChatRateLimitBurst"] = 0
        if hasattr(self, "chat_rate_limit_duration"):
            result["ChatRateLimitDuration"] = int(self.chat_rate_limit_duration)
        elif include_empty:
            result["ChatRateLimitDuration"] = 0
        if hasattr(self, "concurrent_users_limit"):
            result["ConcurrentUsersLimit"] = int(self.concurrent_users_limit)
        elif include_empty:
            result["ConcurrentUsersLimit"] = 0
        if hasattr(self, "enable_profanity_filter"):
            result["EnableProfanityFilter"] = bool(self.enable_profanity_filter)
        elif include_empty:
            result["EnableProfanityFilter"] = False
        if hasattr(self, "filter_app_name"):
            result["FilterAppName"] = str(self.filter_app_name)
        elif include_empty:
            result["FilterAppName"] = ""
        if hasattr(self, "filter_param"):
            result["FilterParam"] = str(self.filter_param)
        elif include_empty:
            result["FilterParam"] = ""
        if hasattr(self, "filter_type"):
            result["FilterType"] = str(self.filter_type)
        elif include_empty:
            result["FilterType"] = ""
        if hasattr(self, "general_rate_limit_burst"):
            result["GeneralRateLimitBurst"] = int(self.general_rate_limit_burst)
        elif include_empty:
            result["GeneralRateLimitBurst"] = 0
        if hasattr(self, "general_rate_limit_duration"):
            result["GeneralRateLimitDuration"] = int(self.general_rate_limit_duration)
        elif include_empty:
            result["GeneralRateLimitDuration"] = 0
        if hasattr(self, "namespace"):
            result["Namespace"] = str(self.namespace)
        elif include_empty:
            result["Namespace"] = ""
        if hasattr(self, "shard_capacity_limit"):
            result["ShardCapacityLimit"] = int(self.shard_capacity_limit)
        elif include_empty:
            result["ShardCapacityLimit"] = 0
        if hasattr(self, "shard_default_limit"):
            result["ShardDefaultLimit"] = int(self.shard_default_limit)
        elif include_empty:
            result["ShardDefaultLimit"] = 0
        if hasattr(self, "shard_hard_limit"):
            result["ShardHardLimit"] = int(self.shard_hard_limit)
        elif include_empty:
            result["ShardHardLimit"] = 0
        if hasattr(self, "spam_chat_burst"):
            result["SpamChatBurst"] = int(self.spam_chat_burst)
        elif include_empty:
            result["SpamChatBurst"] = 0
        if hasattr(self, "spam_chat_duration"):
            result["SpamChatDuration"] = int(self.spam_chat_duration)
        elif include_empty:
            result["SpamChatDuration"] = 0
        if hasattr(self, "spam_mute_duration"):
            result["SpamMuteDuration"] = int(self.spam_mute_duration)
        elif include_empty:
            result["SpamMuteDuration"] = 0
        if hasattr(self, "default_dictionary_loaded"):
            result["defaultDictionaryLoaded"] = bool(self.default_dictionary_loaded)
        elif include_empty:
            result["defaultDictionaryLoaded"] = False
        if hasattr(self, "enable_clan_chat"):
            result["enableClanChat"] = bool(self.enable_clan_chat)
        elif include_empty:
            result["enableClanChat"] = False
        if hasattr(self, "enable_manual_topic_creation"):
            result["EnableManualTopicCreation"] = bool(
                self.enable_manual_topic_creation
            )
        elif include_empty:
            result["EnableManualTopicCreation"] = False
        if hasattr(self, "max_chat_message_length"):
            result["maxChatMessageLength"] = int(self.max_chat_message_length)
        elif include_empty:
            result["maxChatMessageLength"] = 0
        if hasattr(self, "use_default_dictionary"):
            result["useDefaultDictionary"] = bool(self.use_default_dictionary)
        elif include_empty:
            result["useDefaultDictionary"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        chat_rate_limit_burst: int,
        chat_rate_limit_duration: int,
        concurrent_users_limit: int,
        enable_profanity_filter: bool,
        filter_app_name: str,
        filter_param: str,
        filter_type: str,
        general_rate_limit_burst: int,
        general_rate_limit_duration: int,
        namespace: str,
        shard_capacity_limit: int,
        shard_default_limit: int,
        shard_hard_limit: int,
        spam_chat_burst: int,
        spam_chat_duration: int,
        spam_mute_duration: int,
        default_dictionary_loaded: Optional[bool] = None,
        enable_clan_chat: Optional[bool] = None,
        enable_manual_topic_creation: Optional[bool] = None,
        max_chat_message_length: Optional[int] = None,
        use_default_dictionary: Optional[bool] = None,
        **kwargs,
    ) -> ModelsConfig:
        instance = cls()
        instance.chat_rate_limit_burst = chat_rate_limit_burst
        instance.chat_rate_limit_duration = chat_rate_limit_duration
        instance.concurrent_users_limit = concurrent_users_limit
        instance.enable_profanity_filter = enable_profanity_filter
        instance.filter_app_name = filter_app_name
        instance.filter_param = filter_param
        instance.filter_type = filter_type
        instance.general_rate_limit_burst = general_rate_limit_burst
        instance.general_rate_limit_duration = general_rate_limit_duration
        instance.namespace = namespace
        instance.shard_capacity_limit = shard_capacity_limit
        instance.shard_default_limit = shard_default_limit
        instance.shard_hard_limit = shard_hard_limit
        instance.spam_chat_burst = spam_chat_burst
        instance.spam_chat_duration = spam_chat_duration
        instance.spam_mute_duration = spam_mute_duration
        if default_dictionary_loaded is not None:
            instance.default_dictionary_loaded = default_dictionary_loaded
        if enable_clan_chat is not None:
            instance.enable_clan_chat = enable_clan_chat
        if enable_manual_topic_creation is not None:
            instance.enable_manual_topic_creation = enable_manual_topic_creation
        if max_chat_message_length is not None:
            instance.max_chat_message_length = max_chat_message_length
        if use_default_dictionary is not None:
            instance.use_default_dictionary = use_default_dictionary
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ModelsConfig:
        instance = cls()
        if not dict_:
            return instance
        if "ChatRateLimitBurst" in dict_ and dict_["ChatRateLimitBurst"] is not None:
            instance.chat_rate_limit_burst = int(dict_["ChatRateLimitBurst"])
        elif include_empty:
            instance.chat_rate_limit_burst = 0
        if (
            "ChatRateLimitDuration" in dict_
            and dict_["ChatRateLimitDuration"] is not None
        ):
            instance.chat_rate_limit_duration = int(dict_["ChatRateLimitDuration"])
        elif include_empty:
            instance.chat_rate_limit_duration = 0
        if (
            "ConcurrentUsersLimit" in dict_
            and dict_["ConcurrentUsersLimit"] is not None
        ):
            instance.concurrent_users_limit = int(dict_["ConcurrentUsersLimit"])
        elif include_empty:
            instance.concurrent_users_limit = 0
        if (
            "EnableProfanityFilter" in dict_
            and dict_["EnableProfanityFilter"] is not None
        ):
            instance.enable_profanity_filter = bool(dict_["EnableProfanityFilter"])
        elif include_empty:
            instance.enable_profanity_filter = False
        if "FilterAppName" in dict_ and dict_["FilterAppName"] is not None:
            instance.filter_app_name = str(dict_["FilterAppName"])
        elif include_empty:
            instance.filter_app_name = ""
        if "FilterParam" in dict_ and dict_["FilterParam"] is not None:
            instance.filter_param = str(dict_["FilterParam"])
        elif include_empty:
            instance.filter_param = ""
        if "FilterType" in dict_ and dict_["FilterType"] is not None:
            instance.filter_type = str(dict_["FilterType"])
        elif include_empty:
            instance.filter_type = ""
        if (
            "GeneralRateLimitBurst" in dict_
            and dict_["GeneralRateLimitBurst"] is not None
        ):
            instance.general_rate_limit_burst = int(dict_["GeneralRateLimitBurst"])
        elif include_empty:
            instance.general_rate_limit_burst = 0
        if (
            "GeneralRateLimitDuration" in dict_
            and dict_["GeneralRateLimitDuration"] is not None
        ):
            instance.general_rate_limit_duration = int(
                dict_["GeneralRateLimitDuration"]
            )
        elif include_empty:
            instance.general_rate_limit_duration = 0
        if "Namespace" in dict_ and dict_["Namespace"] is not None:
            instance.namespace = str(dict_["Namespace"])
        elif include_empty:
            instance.namespace = ""
        if "ShardCapacityLimit" in dict_ and dict_["ShardCapacityLimit"] is not None:
            instance.shard_capacity_limit = int(dict_["ShardCapacityLimit"])
        elif include_empty:
            instance.shard_capacity_limit = 0
        if "ShardDefaultLimit" in dict_ and dict_["ShardDefaultLimit"] is not None:
            instance.shard_default_limit = int(dict_["ShardDefaultLimit"])
        elif include_empty:
            instance.shard_default_limit = 0
        if "ShardHardLimit" in dict_ and dict_["ShardHardLimit"] is not None:
            instance.shard_hard_limit = int(dict_["ShardHardLimit"])
        elif include_empty:
            instance.shard_hard_limit = 0
        if "SpamChatBurst" in dict_ and dict_["SpamChatBurst"] is not None:
            instance.spam_chat_burst = int(dict_["SpamChatBurst"])
        elif include_empty:
            instance.spam_chat_burst = 0
        if "SpamChatDuration" in dict_ and dict_["SpamChatDuration"] is not None:
            instance.spam_chat_duration = int(dict_["SpamChatDuration"])
        elif include_empty:
            instance.spam_chat_duration = 0
        if "SpamMuteDuration" in dict_ and dict_["SpamMuteDuration"] is not None:
            instance.spam_mute_duration = int(dict_["SpamMuteDuration"])
        elif include_empty:
            instance.spam_mute_duration = 0
        if (
            "defaultDictionaryLoaded" in dict_
            and dict_["defaultDictionaryLoaded"] is not None
        ):
            instance.default_dictionary_loaded = bool(dict_["defaultDictionaryLoaded"])
        elif include_empty:
            instance.default_dictionary_loaded = False
        if "enableClanChat" in dict_ and dict_["enableClanChat"] is not None:
            instance.enable_clan_chat = bool(dict_["enableClanChat"])
        elif include_empty:
            instance.enable_clan_chat = False
        if (
            "EnableManualTopicCreation" in dict_
            and dict_["EnableManualTopicCreation"] is not None
        ):
            instance.enable_manual_topic_creation = bool(
                dict_["EnableManualTopicCreation"]
            )
        elif include_empty:
            instance.enable_manual_topic_creation = False
        if (
            "maxChatMessageLength" in dict_
            and dict_["maxChatMessageLength"] is not None
        ):
            instance.max_chat_message_length = int(dict_["maxChatMessageLength"])
        elif include_empty:
            instance.max_chat_message_length = 0
        if (
            "useDefaultDictionary" in dict_
            and dict_["useDefaultDictionary"] is not None
        ):
            instance.use_default_dictionary = bool(dict_["useDefaultDictionary"])
        elif include_empty:
            instance.use_default_dictionary = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ModelsConfig, List[ModelsConfig], Dict[Any, ModelsConfig]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "ChatRateLimitBurst": "chat_rate_limit_burst",
            "ChatRateLimitDuration": "chat_rate_limit_duration",
            "ConcurrentUsersLimit": "concurrent_users_limit",
            "EnableProfanityFilter": "enable_profanity_filter",
            "FilterAppName": "filter_app_name",
            "FilterParam": "filter_param",
            "FilterType": "filter_type",
            "GeneralRateLimitBurst": "general_rate_limit_burst",
            "GeneralRateLimitDuration": "general_rate_limit_duration",
            "Namespace": "namespace",
            "ShardCapacityLimit": "shard_capacity_limit",
            "ShardDefaultLimit": "shard_default_limit",
            "ShardHardLimit": "shard_hard_limit",
            "SpamChatBurst": "spam_chat_burst",
            "SpamChatDuration": "spam_chat_duration",
            "SpamMuteDuration": "spam_mute_duration",
            "defaultDictionaryLoaded": "default_dictionary_loaded",
            "enableClanChat": "enable_clan_chat",
            "EnableManualTopicCreation": "enable_manual_topic_creation",
            "maxChatMessageLength": "max_chat_message_length",
            "useDefaultDictionary": "use_default_dictionary",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "ChatRateLimitBurst": True,
            "ChatRateLimitDuration": True,
            "ConcurrentUsersLimit": True,
            "EnableProfanityFilter": True,
            "FilterAppName": True,
            "FilterParam": True,
            "FilterType": True,
            "GeneralRateLimitBurst": True,
            "GeneralRateLimitDuration": True,
            "Namespace": True,
            "ShardCapacityLimit": True,
            "ShardDefaultLimit": True,
            "ShardHardLimit": True,
            "SpamChatBurst": True,
            "SpamChatDuration": True,
            "SpamMuteDuration": True,
            "defaultDictionaryLoaded": False,
            "enableClanChat": False,
            "EnableManualTopicCreation": False,
            "maxChatMessageLength": False,
            "useDefaultDictionary": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsConfigExport(Model):
    """Models config export (models.ConfigExport)

    Properties:
        chat_rate_limit_burst: (chatRateLimitBurst) REQUIRED int

        chat_rate_limit_duration: (chatRateLimitDuration) REQUIRED int

        concurrent_users_limit: (concurrentUsersLimit) REQUIRED int

        general_rate_limit_burst: (generalRateLimitBurst) REQUIRED int

        general_rate_limit_duration: (generalRateLimitDuration) REQUIRED int

        namespace: (namespace) REQUIRED str

        enable_clan_chat: (enableClanChat) OPTIONAL bool

        enable_manual_topic_creation: (enableManualTopicCreation) OPTIONAL bool

        enable_profanity_filter: (enableProfanityFilter) OPTIONAL bool

        filter_app_name: (filterAppName) OPTIONAL str

        filter_param: (filterParam) OPTIONAL str

        filter_type: (filterType) OPTIONAL str

        shard_capacity_limit: (shardCapacityLimit) OPTIONAL int

        shard_default_limit: (shardDefaultLimit) OPTIONAL int

        shard_hard_limit: (shardHardLimit) OPTIONAL int

        spam_chat_burst: (spamChatBurst) OPTIONAL int

        spam_chat_duration: (spamChatDuration) OPTIONAL int

        spam_mute_duration: (spamMuteDuration) OPTIONAL int
    """

    # region fields

    chat_rate_limit_burst: int  # REQUIRED
    chat_rate_limit_duration: int  # REQUIRED
    concurrent_users_limit: int  # REQUIRED
    general_rate_limit_burst: int  # REQUIRED
    general_rate_limit_duration: int  # REQUIRED
    namespace: str  # REQUIRED
    enable_clan_chat: bool  # OPTIONAL
    enable_manual_topic_creation: bool  # OPTIONAL
    enable_profanity_filter: bool  # OPTIONAL
    filter_app_name: str  # OPTIONAL
    filter_param: str  # OPTIONAL
    filter_type: str  # OPTIONAL
    shard_capacity_limit: int  # OPTIONAL
    shard_default_limit: int  # OPTIONAL
    shard_hard_limit: int  # OPTIONAL
    spam_chat_burst: int  # OPTIONAL
    spam_chat_duration: int  # OPTIONAL
    spam_mute_duration: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_chat_rate_limit_burst(self, value: int) -> ModelsConfigExport:
        self.chat_rate_limit_burst = value
        return self

    def with_chat_rate_limit_duration(self, value: int) -> ModelsConfigExport:
        self.chat_rate_limit_duration = value
        return self

    def with_concurrent_users_limit(self, value: int) -> ModelsConfigExport:
        self.concurrent_users_limit = value
        return self

    def with_general_rate_limit_burst(self, value: int) -> ModelsConfigExport:
        self.general_rate_limit_burst = value
        return self

    def with_general_rate_limit_duration(self, value: int) -> ModelsConfigExport:
        self.general_rate_limit_duration = value
        return self

    def with_namespace(self, value: str) -> ModelsConfigExport:
        self.namespace = value
        return self

    def with_enable_clan_chat(self, value: bool) -> ModelsConfigExport:
        self.enable_clan_chat = value
        return self

    def with_enable_manual_topic_creation(self, value: bool) -> ModelsConfigExport:
        self.enable_manual_topic_creation = value
        return self

    def with_enable_profanity_filter(self, value: bool) -> ModelsConfigExport:
        self.enable_profanity_filter = value
        return self

    def with_filter_app_name(self, value: str) -> ModelsConfigExport:
        self.filter_app_name = value
        return self

    def with_filter_param(self, value: str) -> ModelsConfigExport:
        self.filter_param = value
        return self

    def with_filter_type(self, value: str) -> ModelsConfigExport:
        self.filter_type = value
        return self

    def with_shard_capacity_limit(self, value: int) -> ModelsConfigExport:
        self.shard_capacity_limit = value
        return self

    def with_shard_default_limit(self, value: int) -> ModelsConfigExport:
        self.shard_default_limit = value
        return self

    def with_shard_hard_limit(self, value: int) -> ModelsConfigExport:
        self.shard_hard_limit = value
        return self

    def with_spam_chat_burst(self, value: int) -> ModelsConfigExport:
        self.spam_chat_burst = value
        return self

    def with_spam_chat_duration(self, value: int) -> ModelsConfigExport:
        self.spam_chat_duration = value
        return self

    def with_spam_mute_duration(self, value: int) -> ModelsConfigExport:
        self.spam_mute_duration = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "chat_rate_limit_burst"):
            result["chatRateLimitBurst"] = int(self.chat_rate_limit_burst)
        elif include_empty:
            result["chatRateLimitBurst"] = 0
        if hasattr(self, "chat_rate_limit_duration"):
            result["chatRateLimitDuration"] = int(self.chat_rate_limit_duration)
        elif include_empty:
            result["chatRateLimitDuration"] = 0
        if hasattr(self, "concurrent_users_limit"):
            result["concurrentUsersLimit"] = int(self.concurrent_users_limit)
        elif include_empty:
            result["concurrentUsersLimit"] = 0
        if hasattr(self, "general_rate_limit_burst"):
            result["generalRateLimitBurst"] = int(self.general_rate_limit_burst)
        elif include_empty:
            result["generalRateLimitBurst"] = 0
        if hasattr(self, "general_rate_limit_duration"):
            result["generalRateLimitDuration"] = int(self.general_rate_limit_duration)
        elif include_empty:
            result["generalRateLimitDuration"] = 0
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "enable_clan_chat"):
            result["enableClanChat"] = bool(self.enable_clan_chat)
        elif include_empty:
            result["enableClanChat"] = False
        if hasattr(self, "enable_manual_topic_creation"):
            result["enableManualTopicCreation"] = bool(
                self.enable_manual_topic_creation
            )
        elif include_empty:
            result["enableManualTopicCreation"] = False
        if hasattr(self, "enable_profanity_filter"):
            result["enableProfanityFilter"] = bool(self.enable_profanity_filter)
        elif include_empty:
            result["enableProfanityFilter"] = False
        if hasattr(self, "filter_app_name"):
            result["filterAppName"] = str(self.filter_app_name)
        elif include_empty:
            result["filterAppName"] = ""
        if hasattr(self, "filter_param"):
            result["filterParam"] = str(self.filter_param)
        elif include_empty:
            result["filterParam"] = ""
        if hasattr(self, "filter_type"):
            result["filterType"] = str(self.filter_type)
        elif include_empty:
            result["filterType"] = ""
        if hasattr(self, "shard_capacity_limit"):
            result["shardCapacityLimit"] = int(self.shard_capacity_limit)
        elif include_empty:
            result["shardCapacityLimit"] = 0
        if hasattr(self, "shard_default_limit"):
            result["shardDefaultLimit"] = int(self.shard_default_limit)
        elif include_empty:
            result["shardDefaultLimit"] = 0
        if hasattr(self, "shard_hard_limit"):
            result["shardHardLimit"] = int(self.shard_hard_limit)
        elif include_empty:
            result["shardHardLimit"] = 0
        if hasattr(self, "spam_chat_burst"):
            result["spamChatBurst"] = int(self.spam_chat_burst)
        elif include_empty:
            result["spamChatBurst"] = 0
        if hasattr(self, "spam_chat_duration"):
            result["spamChatDuration"] = int(self.spam_chat_duration)
        elif include_empty:
            result["spamChatDuration"] = 0
        if hasattr(self, "spam_mute_duration"):
            result["spamMuteDuration"] = int(self.spam_mute_duration)
        elif include_empty:
            result["spamMuteDuration"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        chat_rate_limit_burst: int,
        chat_rate_limit_duration: int,
        concurrent_users_limit: int,
        general_rate_limit_burst: int,
        general_rate_limit_duration: int,
        namespace: str,
        enable_clan_chat: Optional[bool] = None,
        enable_manual_topic_creation: Optional[bool] = None,
        enable_profanity_filter: Optional[bool] = None,
        filter_app_name: Optional[str] = None,
        filter_param: Optional[str] = None,
        filter_type: Optional[str] = None,
        shard_capacity_limit: Optional[int] = None,
        shard_default_limit: Optional[int] = None,
        shard_hard_limit: Optional[int] = None,
        spam_chat_burst: Optional[int] = None,
        spam_chat_duration: Optional[int] = None,
        spam_mute_duration: Optional[int] = None,
        **kwargs,
    ) -> ModelsConfigExport:
        instance = cls()
        instance.chat_rate_limit_burst = chat_rate_limit_burst
        instance.chat_rate_limit_duration = chat_rate_limit_duration
        instance.concurrent_users_limit = concurrent_users_limit
        instance.general_rate_limit_burst = general_rate_limit_burst
        instance.general_rate_limit_duration = general_rate_limit_duration
        instance.namespace = namespace
        if enable_clan_chat is not None:
            instance.enable_clan_chat = enable_clan_chat
        if enable_manual_topic_creation is not None:
            instance.enable_manual_topic_creation = enable_manual_topic_creation
        if enable_profanity_filter is not None:
            instance.enable_profanity_filter = enable_profanity_filter
        if filter_app_name is not None:
            instance.filter_app_name = filter_app_name
        if filter_param is not None:
            instance.filter_param = filter_param
        if filter_type is not None:
            instance.filter_type = filter_type
        if shard_capacity_limit is not None:
            instance.shard_capacity_limit = shard_capacity_limit
        if shard_default_limit is not None:
            instance.shard_default_limit = shard_default_limit
        if shard_hard_limit is not None:
            instance.shard_hard_limit = shard_hard_limit
        if spam_chat_burst is not None:
            instance.spam_chat_burst = spam_chat_burst
        if spam_chat_duration is not None:
            instance.spam_chat_duration = spam_chat_duration
        if spam_mute_duration is not None:
            instance.spam_mute_duration = spam_mute_duration
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsConfigExport:
        instance = cls()
        if not dict_:
            return instance
        if "chatRateLimitBurst" in dict_ and dict_["chatRateLimitBurst"] is not None:
            instance.chat_rate_limit_burst = int(dict_["chatRateLimitBurst"])
        elif include_empty:
            instance.chat_rate_limit_burst = 0
        if (
            "chatRateLimitDuration" in dict_
            and dict_["chatRateLimitDuration"] is not None
        ):
            instance.chat_rate_limit_duration = int(dict_["chatRateLimitDuration"])
        elif include_empty:
            instance.chat_rate_limit_duration = 0
        if (
            "concurrentUsersLimit" in dict_
            and dict_["concurrentUsersLimit"] is not None
        ):
            instance.concurrent_users_limit = int(dict_["concurrentUsersLimit"])
        elif include_empty:
            instance.concurrent_users_limit = 0
        if (
            "generalRateLimitBurst" in dict_
            and dict_["generalRateLimitBurst"] is not None
        ):
            instance.general_rate_limit_burst = int(dict_["generalRateLimitBurst"])
        elif include_empty:
            instance.general_rate_limit_burst = 0
        if (
            "generalRateLimitDuration" in dict_
            and dict_["generalRateLimitDuration"] is not None
        ):
            instance.general_rate_limit_duration = int(
                dict_["generalRateLimitDuration"]
            )
        elif include_empty:
            instance.general_rate_limit_duration = 0
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "enableClanChat" in dict_ and dict_["enableClanChat"] is not None:
            instance.enable_clan_chat = bool(dict_["enableClanChat"])
        elif include_empty:
            instance.enable_clan_chat = False
        if (
            "enableManualTopicCreation" in dict_
            and dict_["enableManualTopicCreation"] is not None
        ):
            instance.enable_manual_topic_creation = bool(
                dict_["enableManualTopicCreation"]
            )
        elif include_empty:
            instance.enable_manual_topic_creation = False
        if (
            "enableProfanityFilter" in dict_
            and dict_["enableProfanityFilter"] is not None
        ):
            instance.enable_profanity_filter = bool(dict_["enableProfanityFilter"])
        elif include_empty:
            instance.enable_profanity_filter = False
        if "filterAppName" in dict_ and dict_["filterAppName"] is not None:
            instance.filter_app_name = str(dict_["filterAppName"])
        elif include_empty:
            instance.filter_app_name = ""
        if "filterParam" in dict_ and dict_["filterParam"] is not None:
            instance.filter_param = str(dict_["filterParam"])
        elif include_empty:
            instance.filter_param = ""
        if "filterType" in dict_ and dict_["filterType"] is not None:
            instance.filter_type = str(dict_["filterType"])
        elif include_empty:
            instance.filter_type = ""
        if "shardCapacityLimit" in dict_ and dict_["shardCapacityLimit"] is not None:
            instance.shard_capacity_limit = int(dict_["shardCapacityLimit"])
        elif include_empty:
            instance.shard_capacity_limit = 0
        if "shardDefaultLimit" in dict_ and dict_["shardDefaultLimit"] is not None:
            instance.shard_default_limit = int(dict_["shardDefaultLimit"])
        elif include_empty:
            instance.shard_default_limit = 0
        if "shardHardLimit" in dict_ and dict_["shardHardLimit"] is not None:
            instance.shard_hard_limit = int(dict_["shardHardLimit"])
        elif include_empty:
            instance.shard_hard_limit = 0
        if "spamChatBurst" in dict_ and dict_["spamChatBurst"] is not None:
            instance.spam_chat_burst = int(dict_["spamChatBurst"])
        elif include_empty:
            instance.spam_chat_burst = 0
        if "spamChatDuration" in dict_ and dict_["spamChatDuration"] is not None:
            instance.spam_chat_duration = int(dict_["spamChatDuration"])
        elif include_empty:
            instance.spam_chat_duration = 0
        if "spamMuteDuration" in dict_ and dict_["spamMuteDuration"] is not None:
            instance.spam_mute_duration = int(dict_["spamMuteDuration"])
        elif include_empty:
            instance.spam_mute_duration = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsConfigExport]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsConfigExport]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsConfigExport, List[ModelsConfigExport], Dict[Any, ModelsConfigExport]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "chatRateLimitBurst": "chat_rate_limit_burst",
            "chatRateLimitDuration": "chat_rate_limit_duration",
            "concurrentUsersLimit": "concurrent_users_limit",
            "generalRateLimitBurst": "general_rate_limit_burst",
            "generalRateLimitDuration": "general_rate_limit_duration",
            "namespace": "namespace",
            "enableClanChat": "enable_clan_chat",
            "enableManualTopicCreation": "enable_manual_topic_creation",
            "enableProfanityFilter": "enable_profanity_filter",
            "filterAppName": "filter_app_name",
            "filterParam": "filter_param",
            "filterType": "filter_type",
            "shardCapacityLimit": "shard_capacity_limit",
            "shardDefaultLimit": "shard_default_limit",
            "shardHardLimit": "shard_hard_limit",
            "spamChatBurst": "spam_chat_burst",
            "spamChatDuration": "spam_chat_duration",
            "spamMuteDuration": "spam_mute_duration",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "chatRateLimitBurst": True,
            "chatRateLimitDuration": True,
            "concurrentUsersLimit": True,
            "generalRateLimitBurst": True,
            "generalRateLimitDuration": True,
            "namespace": True,
            "enableClanChat": False,
            "enableManualTopicCreation": False,
            "enableProfanityFilter": False,
            "filterAppName": False,
            "filterParam": False,
            "filterType": False,
            "shardCapacityLimit": False,
            "shardDefaultLimit": False,
            "shardHardLimit": False,
            "spamChatBurst": False,
            "spamChatDuration": False,
            "spamMuteDuration": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import deprecated
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApiAddMemberParams
from ..models import ApiCreateNamespaceTopicParams
from ..models import ApiCreateTopicParams
from ..models import ApiCreateTopicResponse
from ..models import ApiMutedTopicResponse
from ..models import ApiMuteUserRequest
from ..models import ApiSendChatParams
from ..models import ApiUnmuteUserRequest
from ..models import ApiUpdateTopicParams
from ..models import MessageActionAddUserToTopicResult
from ..models import MessageActionDeleteTopicResult
from ..models import ModelsBanTopicMemberParam
from ..models import ModelsBanTopicMemberResult
from ..models import ModelsChannelTopicResponse
from ..models import ModelsChannelTopicSummaryResponse
from ..models import ModelsChannelTopicWithPaginationResponse
from ..models import ModelsChatMessageResponse
from ..models import ModelsChatMessageWithPaginationResponse
from ..models import ModelsMessageRequest
from ..models import ModelsMessageResultWithAttributes
from ..models import ModelsPublicBanTopicMembersRequest
from ..models import ModelsPublicBanTopicMembersResponse
from ..models import ModelsPublicUnbanTopicMembersRequest
from ..models import ModelsPublicUnbanTopicMembersResponse
from ..models import ModelsTopicInfo
from ..models import ModelsTopicLogWithPaginationResponse
from ..models import ModelsTopicMemberWithPaginationResponse
from ..models import ModelsTopicResponse
from ..models import ModelsUnbanTopicMemberParam
from ..models import ModelsUnbanTopicMemberResult
from ..models import RestapiErrorResponseBody

from ..operations.topic import AdminAddTopicMember
from ..operations.topic import AdminBanTopicMembers
from ..operations.topic import AdminChannelTopicInfo
from ..operations.topic import AdminChannelTopicList
from ..operations.topic import AdminChannelTopicSummary
from ..operations.topic import AdminChatHistory
from ..operations.topic import AdminCreateNamespaceTopic
from ..operations.topic import AdminCreateTopic
from ..operations.topic import AdminDeleteChat
from ..operations.topic import AdminDeleteTopic
from ..operations.topic import AdminFilterChatMessage
from ..operations.topic import AdminQueryTopic
from ..operations.topic import (
    AdminQueryTopicTopicSubTypeEnum,
    AdminQueryTopicTopicTypeEnum,
)
from ..operations.topic import AdminQueryTopicLog
from ..operations.topic import AdminQueryUsersTopic
from ..operations.topic import (
    AdminQueryUsersTopicTopicSubTypeEnum,
    AdminQueryUsersTopicTopicTypeEnum,
)
from ..operations.topic import AdminRemoveTopicMember
from ..operations.topic import AdminSendChat
from ..operations.topic import AdminTopicChatHistory
from ..operations.topic import AdminTopicList
from ..operations.topic import AdminTopicMembers
from ..operations.topic import AdminTopicShards
from ..operations.topic import AdminUnbanTopicMembers
from ..operations.topic import AdminUpdateTopic
from ..operations.topic import PublicBanTopicMembers
from ..operations.topic import PublicChatHistory
from ..operations.topic import PublicDeleteChat
from ..operations.topic import PublicGetMutedTopics
from ..operations.topic import PublicMuteUser
from ..operations.topic import PublicTopicList
from ..operations.topic import PublicUnbanTopicMembers
from ..operations.topic import PublicUnmuteUser
from ..models import ModelsMessageRequestTopicTypeEnum


@same_doc_as(AdminAddTopicMember)
def admin_add_topic_member(
    body: ApiAddMemberParams,
    topic: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin add user to topic (adminAddTopicMember)

    Add new member for topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/user/{userId}

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAddMemberParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - MessageActionAddUserToTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddTopicMember.create(
        body=body,
        topic=topic,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminAddTopicMember)
async def admin_add_topic_member_async(
    body: ApiAddMemberParams,
    topic: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin add user to topic (adminAddTopicMember)

    Add new member for topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/user/{userId}

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAddMemberParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - MessageActionAddUserToTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddTopicMember.create(
        body=body,
        topic=topic,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminBanTopicMembers)
def admin_ban_topic_members(
    body: ModelsBanTopicMemberParam,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins ban user in group topic (adminBanTopicMembers)

    Ban users in some topic. banned user not assigned to shard for channel topic, and cannot send and query chat.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/ban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsBanTopicMemberParam in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsBanTopicMemberResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminBanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminBanTopicMembers)
async def admin_ban_topic_members_async(
    body: ModelsBanTopicMemberParam,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins ban user in group topic (adminBanTopicMembers)

    Ban users in some topic. banned user not assigned to shard for channel topic, and cannot send and query chat.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/ban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsBanTopicMemberParam in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsBanTopicMemberResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminBanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminChannelTopicInfo)
def admin_channel_topic_info(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get channel topic detail (adminChannelTopicInfo)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/channel

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelTopicResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Bad Request)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicInfo.create(
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminChannelTopicInfo)
async def admin_channel_topic_info_async(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get channel topic detail (adminChannelTopicInfo)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/channel

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelTopicResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Bad Request)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicInfo.create(
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminChannelTopicList)
def admin_channel_topic_list(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_name: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get list of channel topic (adminChannelTopicList)

    Get channel chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/channel

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_name: (topicName) OPTIONAL str in query

    Responses:
        200: OK - ModelsChannelTopicWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicList.create(
        limit=limit,
        offset=offset,
        topic_name=topic_name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminChannelTopicList)
async def admin_channel_topic_list_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_name: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get list of channel topic (adminChannelTopicList)

    Get channel chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/channel

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_name: (topicName) OPTIONAL str in query

    Responses:
        200: OK - ModelsChannelTopicWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicList.create(
        limit=limit,
        offset=offset,
        topic_name=topic_name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminChannelTopicSummary)
def admin_channel_topic_summary(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get channel topic summary (adminChannelTopicSummary)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/channel/summary

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelTopicSummaryResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicSummary.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminChannelTopicSummary)
async def admin_channel_topic_summary_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get channel topic summary (adminChannelTopicSummary)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/channel/summary

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelTopicSummaryResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChannelTopicSummary.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminChatHistory)
def admin_chat_history(
    chat_id: Optional[List[str]] = None,
    end_created_at: Optional[int] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    sender_user_id: Optional[str] = None,
    shard_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    topic: Optional[List[str]] = None,
    unfiltered: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat history (adminChatHistory)

    Get chat history in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        chat_id: (chatId) OPTIONAL List[str] in query

        end_created_at: (endCreatedAt) OPTIONAL int in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        shard_id: (shardId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        topic: (topic) OPTIONAL List[str] in query

        unfiltered: (unfiltered) OPTIONAL bool in query

    Responses:
        200: OK - ModelsChatMessageWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChatHistory.create(
        chat_id=chat_id,
        end_created_at=end_created_at,
        keyword=keyword,
        limit=limit,
        offset=offset,
        order=order,
        sender_user_id=sender_user_id,
        shard_id=shard_id,
        start_created_at=start_created_at,
        topic=topic,
        unfiltered=unfiltered,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminChatHistory)
async def admin_chat_history_async(
    chat_id: Optional[List[str]] = None,
    end_created_at: Optional[int] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    sender_user_id: Optional[str] = None,
    shard_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    topic: Optional[List[str]] = None,
    unfiltered: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat history (adminChatHistory)

    Get chat history in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        chat_id: (chatId) OPTIONAL List[str] in query

        end_created_at: (endCreatedAt) OPTIONAL int in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        shard_id: (shardId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        topic: (topic) OPTIONAL List[str] in query

        unfiltered: (unfiltered) OPTIONAL bool in query

    Responses:
        200: OK - ModelsChatMessageWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChatHistory.create(
        chat_id=chat_id,
        end_created_at=end_created_at,
        keyword=keyword,
        limit=limit,
        offset=offset,
        order=order,
        sender_user_id=sender_user_id,
        shard_id=shard_id,
        start_created_at=start_created_at,
        topic=topic,
        unfiltered=unfiltered,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminCreateNamespaceTopic)
def admin_create_namespace_topic(
    body: ApiCreateNamespaceTopicParams,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to create namespace group. Message that send to this group send to connected user in a namespace (adminCreateNamespaceTopic)

    Create new namespace group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/namespace-topic

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiCreateNamespaceTopicParams in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateNamespaceTopic.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateNamespaceTopic)
async def admin_create_namespace_topic_async(
    body: ApiCreateNamespaceTopicParams,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to create namespace group. Message that send to this group send to connected user in a namespace (adminCreateNamespaceTopic)

    Create new namespace group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/namespace-topic

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiCreateNamespaceTopicParams in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateNamespaceTopic.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminCreateTopic)
def admin_create_topic(
    body: ApiCreateTopicParams,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to create group. Only group admin can use this operation (adminCreateTopic)

    Create new group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiCreateTopicParams in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateTopic.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateTopic)
async def admin_create_topic_async(
    body: ApiCreateTopicParams,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to create group. Only group admin can use this operation (adminCreateTopic)

    Create new group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiCreateTopicParams in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateTopic.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteChat)
def admin_delete_chat(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins delete chat (adminDeleteChat)

    Delete chat.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats/{chatId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteChat.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteChat)
async def admin_delete_chat_async(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins delete chat (adminDeleteChat)

    Delete chat.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats/{chatId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteChat.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteTopic)
def admin_delete_topic(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to delete group. Only group admin can use this operation (adminDeleteTopic)

    Delete topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - MessageActionDeleteTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteTopic.create(
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteTopic)
async def admin_delete_topic_async(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to delete group. Only group admin can use this operation (adminDeleteTopic)

    Delete topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - MessageActionDeleteTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteTopic.create(
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminFilterChatMessage)
def admin_filter_chat_message(
    body: ModelsMessageRequest,
    detail: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Return filtered chat message (adminFilterChatMessage)

    For testing purpose, doesn't send any message to the topic. Always do filter regardless of enableProfanityFilter configuration.

    Properties:
        url: /chat/admin/namespaces/{namespace}/chat/filter

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsMessageRequest in body

        namespace: (namespace) REQUIRED str in path

        detail: (detail) OPTIONAL bool in query

    Responses:
        200: OK - ModelsMessageResultWithAttributes (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminFilterChatMessage.create(
        body=body,
        detail=detail,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminFilterChatMessage)
async def admin_filter_chat_message_async(
    body: ModelsMessageRequest,
    detail: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Return filtered chat message (adminFilterChatMessage)

    For testing purpose, doesn't send any message to the topic. Always do filter regardless of enableProfanityFilter configuration.

    Properties:
        url: /chat/admin/namespaces/{namespace}/chat/filter

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsMessageRequest in body

        namespace: (namespace) REQUIRED str in path

        detail: (detail) OPTIONAL bool in query

    Responses:
        200: OK - ModelsMessageResultWithAttributes (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminFilterChatMessage.create(
        body=body,
        detail=detail,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryTopic)
def admin_query_topic(
    include_members: Optional[bool] = None,
    include_past_members: Optional[bool] = None,
    include_past_topics: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic: Optional[List[str]] = None,
    topic_sub_type: Optional[Union[str, AdminQueryTopicTopicSubTypeEnum]] = None,
    topic_type: Optional[Union[str, AdminQueryTopicTopicTypeEnum]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query topics (adminQueryTopic)

    Get topics in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topics

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        include_members: (includeMembers) OPTIONAL bool in query

        include_past_members: (includePastMembers) OPTIONAL bool in query

        include_past_topics: (includePastTopics) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic: (topic) OPTIONAL List[str] in query

        topic_sub_type: (topicSubType) OPTIONAL Union[str, TopicSubTypeEnum] in query

        topic_type: (topicType) OPTIONAL Union[str, TopicTypeEnum] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsTopicInfo] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryTopic.create(
        include_members=include_members,
        include_past_members=include_past_members,
        include_past_topics=include_past_topics,
        limit=limit,
        offset=offset,
        topic=topic,
        topic_sub_type=topic_sub_type,
        topic_type=topic_type,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryTopic)
async def admin_query_topic_async(
    include_members: Optional[bool] = None,
    include_past_members: Optional[bool] = None,
    include_past_topics: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic: Optional[List[str]] = None,
    topic_sub_type: Optional[Union[str, AdminQueryTopicTopicSubTypeEnum]] = None,
    topic_type: Optional[Union[str, AdminQueryTopicTopicTypeEnum]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query topics (adminQueryTopic)

    Get topics in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topics

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        include_members: (includeMembers) OPTIONAL bool in query

        include_past_members: (includePastMembers) OPTIONAL bool in query

        include_past_topics: (includePastTopics) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic: (topic) OPTIONAL List[str] in query

        topic_sub_type: (topicSubType) OPTIONAL Union[str, TopicSubTypeEnum] in query

        topic_type: (topicType) OPTIONAL Union[str, TopicTypeEnum] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsTopicInfo] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryTopic.create(
        include_members=include_members,
        include_past_members=include_past_members,
        include_past_topics=include_past_topics,
        limit=limit,
        offset=offset,
        topic=topic,
        topic_sub_type=topic_sub_type,
        topic_type=topic_type,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryTopicLog)
def admin_query_topic_log(
    end_created_at: Optional[int] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sender_user_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    topic_id: Optional[str] = None,
    topic_ids: Optional[List[str]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query topic log (adminQueryTopicLog)

    Get chat log of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/log

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_created_at: (endCreatedAt) OPTIONAL int in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        topic_id: (topicId) OPTIONAL str in query

        topic_ids: (topicIds) OPTIONAL List[str] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelsTopicLogWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryTopicLog.create(
        end_created_at=end_created_at,
        limit=limit,
        offset=offset,
        sender_user_id=sender_user_id,
        start_created_at=start_created_at,
        topic_id=topic_id,
        topic_ids=topic_ids,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryTopicLog)
async def admin_query_topic_log_async(
    end_created_at: Optional[int] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sender_user_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    topic_id: Optional[str] = None,
    topic_ids: Optional[List[str]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query topic log (adminQueryTopicLog)

    Get chat log of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/log

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_created_at: (endCreatedAt) OPTIONAL int in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        topic_id: (topicId) OPTIONAL str in query

        topic_ids: (topicIds) OPTIONAL List[str] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelsTopicLogWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryTopicLog.create(
        end_created_at=end_created_at,
        limit=limit,
        offset=offset,
        sender_user_id=sender_user_id,
        start_created_at=start_created_at,
        topic_id=topic_id,
        topic_ids=topic_ids,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryUsersTopic)
def admin_query_users_topic(
    user_id: str,
    include_past_topics: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_sub_type: Optional[Union[str, AdminQueryUsersTopicTopicSubTypeEnum]] = None,
    topic_type: Optional[Union[str, AdminQueryUsersTopicTopicTypeEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query user's topics (adminQueryUsersTopic)

    Get user's topics in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/users/{userId}/topics

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        include_past_topics: (includePastTopics) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_sub_type: (topicSubType) OPTIONAL Union[str, TopicSubTypeEnum] in query

        topic_type: (topicType) OPTIONAL Union[str, TopicTypeEnum] in query

    Responses:
        200: OK - ModelsTopicLogWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryUsersTopic.create(
        user_id=user_id,
        include_past_topics=include_past_topics,
        limit=limit,
        offset=offset,
        topic_sub_type=topic_sub_type,
        topic_type=topic_type,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryUsersTopic)
async def admin_query_users_topic_async(
    user_id: str,
    include_past_topics: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_sub_type: Optional[Union[str, AdminQueryUsersTopicTopicSubTypeEnum]] = None,
    topic_type: Optional[Union[str, AdminQueryUsersTopicTopicTypeEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query user's topics (adminQueryUsersTopic)

    Get user's topics in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/users/{userId}/topics

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        include_past_topics: (includePastTopics) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_sub_type: (topicSubType) OPTIONAL Union[str, TopicSubTypeEnum] in query

        topic_type: (topicType) OPTIONAL Union[str, TopicTypeEnum] in query

    Responses:
        200: OK - ModelsTopicLogWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminQueryUsersTopic.create(
        user_id=user_id,
        include_past_topics=include_past_topics,
        limit=limit,
        offset=offset,
        topic_sub_type=topic_sub_type,
        topic_type=topic_type,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminRemoveTopicMember)
def admin_remove_topic_member(
    topic: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin remove user from topic (adminRemoveTopicMember)

    Remove member from topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/user/{userId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - MessageActionAddUserToTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminRemoveTopicMember.create(
        topic=topic,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminRemoveTopicMember)
async def admin_remove_topic_member_async(
    topic: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin remove user from topic (adminRemoveTopicMember)

    Remove member from topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/user/{userId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - MessageActionAddUserToTopicResult
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminRemoveTopicMember.create(
        topic=topic,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSendChat)
def admin_send_chat(
    body: ApiSendChatParams,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins send chat to group topic (adminSendChat)

    Send message to chat topic as system.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiSendChatParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSendChat.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSendChat)
async def admin_send_chat_async(
    body: ApiSendChatParams,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins send chat to group topic (adminSendChat)

    Send message to chat topic as system.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiSendChatParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSendChat.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(AdminTopicChatHistory)
def admin_topic_chat_history(
    topic: str,
    end_created_at: Optional[int] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    sender_user_id: Optional[str] = None,
    shard_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    unfiltered: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat history (adminTopicChatHistory)

    Get chat history in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        end_created_at: (endCreatedAt) OPTIONAL int in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        shard_id: (shardId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        unfiltered: (unfiltered) OPTIONAL bool in query

    Responses:
        200: OK - ModelsChatMessageWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicChatHistory.create(
        topic=topic,
        end_created_at=end_created_at,
        keyword=keyword,
        limit=limit,
        offset=offset,
        order=order,
        sender_user_id=sender_user_id,
        shard_id=shard_id,
        start_created_at=start_created_at,
        unfiltered=unfiltered,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AdminTopicChatHistory)
async def admin_topic_chat_history_async(
    topic: str,
    end_created_at: Optional[int] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    sender_user_id: Optional[str] = None,
    shard_id: Optional[str] = None,
    start_created_at: Optional[int] = None,
    unfiltered: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat history (adminTopicChatHistory)

    Get chat history in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        end_created_at: (endCreatedAt) OPTIONAL int in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        sender_user_id: (senderUserId) OPTIONAL str in query

        shard_id: (shardId) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        unfiltered: (unfiltered) OPTIONAL bool in query

    Responses:
        200: OK - ModelsChatMessageWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicChatHistory.create(
        topic=topic,
        end_created_at=end_created_at,
        keyword=keyword,
        limit=limit,
        offset=offset,
        order=order,
        sender_user_id=sender_user_id,
        shard_id=shard_id,
        start_created_at=start_created_at,
        unfiltered=unfiltered,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminTopicList)
def admin_topic_list(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get list of topic (adminTopicList)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_type: (topicType) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsTopicResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicList.create(
        limit=limit,
        offset=offset,
        topic_type=topic_type,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminTopicList)
async def admin_topic_list_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get list of topic (adminTopicList)

    Get chat list of topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_type: (topicType) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsTopicResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicList.create(
        limit=limit,
        offset=offset,
        topic_type=topic_type,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminTopicMembers)
def admin_topic_members(
    topic: str,
    is_banned: Optional[bool] = None,
    is_moderator: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    shard_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get topic member (adminTopicMembers)

    Get topic members.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/members

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        is_banned: (isBanned) OPTIONAL bool in query

        is_moderator: (isModerator) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        shard_id: (shardId) OPTIONAL str in query

    Responses:
        200: OK - ModelsTopicMemberWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicMembers.create(
        topic=topic,
        is_banned=is_banned,
        is_moderator=is_moderator,
        limit=limit,
        offset=offset,
        shard_id=shard_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminTopicMembers)
async def admin_topic_members_async(
    topic: str,
    is_banned: Optional[bool] = None,
    is_moderator: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    shard_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get topic member (adminTopicMembers)

    Get topic members.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/members

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        is_banned: (isBanned) OPTIONAL bool in query

        is_moderator: (isModerator) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        shard_id: (shardId) OPTIONAL str in query

    Responses:
        200: OK - ModelsTopicMemberWithPaginationResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicMembers.create(
        topic=topic,
        is_banned=is_banned,
        is_moderator=is_moderator,
        limit=limit,
        offset=offset,
        shard_id=shard_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminTopicShards)
def admin_topic_shards(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get shard list of topic (adminTopicShards)

    Get shard list from topic.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/shards

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicShards.create(
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminTopicShards)
async def admin_topic_shards_async(
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get shard list of topic (adminTopicShards)

    Get shard list from topic.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/shards

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminTopicShards.create(
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUnbanTopicMembers)
def admin_unban_topic_members(
    body: ModelsUnbanTopicMemberParam,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins unban user in group topic (adminUnbanTopicMembers)

    Unban users in some topic.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/unban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnbanTopicMemberParam in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsUnbanTopicMemberResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUnbanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUnbanTopicMembers)
async def admin_unban_topic_members_async(
    body: ModelsUnbanTopicMemberParam,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admins unban user in group topic (adminUnbanTopicMembers)

    Unban users in some topic.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}/unban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnbanTopicMemberParam in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsUnbanTopicMemberResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUnbanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateTopic)
def admin_update_topic(
    body: ApiUpdateTopicParams,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to update group information. Only group admin can use this operation (adminUpdateTopic)

    Update group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiUpdateTopicParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateTopic.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateTopic)
async def admin_update_topic_async(
    body: ApiUpdateTopicParams,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Use to update group information. Only group admin can use this operation (adminUpdateTopic)

    Update group topic in a namespace.

    Properties:
        url: /chat/admin/namespaces/{namespace}/topic/{topic}

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiUpdateTopicParams in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ApiCreateTopicResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateTopic.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicBanTopicMembers)
def public_ban_topic_members(
    body: ModelsPublicBanTopicMembersRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public ban topic members in a group topic (publicBanTopicMembers)

    Ban topic members in a group topic.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/ban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicBanTopicMembersRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsPublicBanTopicMembersResponse

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicBanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicBanTopicMembers)
async def public_ban_topic_members_async(
    body: ModelsPublicBanTopicMembersRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public ban topic members in a group topic (publicBanTopicMembers)

    Ban topic members in a group topic.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/ban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicBanTopicMembersRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsPublicBanTopicMembersResponse

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicBanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicChatHistory)
def public_chat_history(
    topic: str,
    limit: Optional[int] = None,
    order: Optional[str] = None,
    start_created_at: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get chat history (publicChatHistory)

    get chat history in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicChatHistory.create(
        topic=topic,
        limit=limit,
        order=order,
        start_created_at=start_created_at,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicChatHistory)
async def public_chat_history_async(
    topic: str,
    limit: Optional[int] = None,
    order: Optional[str] = None,
    start_created_at: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get chat history (publicChatHistory)

    get chat history in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/chats

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicChatHistory.create(
        topic=topic,
        limit=limit,
        order=order,
        start_created_at=start_created_at,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicDeleteChat)
def public_delete_chat(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public delete chat (publicDeleteChat)

    Delete chat.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/chats/{chatId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicDeleteChat.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicDeleteChat)
async def public_delete_chat_async(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public delete chat (publicDeleteChat)

    Delete chat.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/chats/{chatId}

        method: DELETE

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicDeleteChat.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetMutedTopics)
def public_get_muted_topics(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get muted at topics (publicGetMutedTopics)

    get chat muted topics in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/muted

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ApiMutedTopicResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetMutedTopics.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetMutedTopics)
async def public_get_muted_topics_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get muted at topics (publicGetMutedTopics)

    get chat muted topics in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/muted

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ApiMutedTopicResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetMutedTopics.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicMuteUser)
def public_mute_user(
    body: ApiMuteUserRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public mute user in a topic (publicMuteUser)

    Mute user.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/mute

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiMuteUserRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicMuteUser.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicMuteUser)
async def public_mute_user_async(
    body: ApiMuteUserRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public mute user in a topic (publicMuteUser)

    Mute user.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/mute

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiMuteUserRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicMuteUser.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicTopicList)
def public_topic_list(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get list of topic (publicTopicList)

    get chat list of topic in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_type: (topicType) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicTopicList.create(
        limit=limit,
        offset=offset,
        topic_type=topic_type,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicTopicList)
async def public_topic_list_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    topic_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get list of topic (publicTopicList)

    get chat list of topic in a namespace.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic

        method: GET

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        topic_type: (topicType) OPTIONAL str in query

    Responses:
        200: OK - List[ModelsChatMessageResponse] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicTopicList.create(
        limit=limit,
        offset=offset,
        topic_type=topic_type,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUnbanTopicMembers)
def public_unban_topic_members(
    body: ModelsPublicUnbanTopicMembersRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public unban topic members in a group topic (publicUnbanTopicMembers)

    Unban topic members in a group topic.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/unban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicUnbanTopicMembersRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsPublicUnbanTopicMembersResponse

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnbanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUnbanTopicMembers)
async def public_unban_topic_members_async(
    body: ModelsPublicUnbanTopicMembersRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public unban topic members in a group topic (publicUnbanTopicMembers)

    Unban topic members in a group topic.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/unban-members

        method: POST

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicUnbanTopicMembersRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsPublicUnbanTopicMembersResponse

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnbanTopicMembers.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUnmuteUser)
def public_unmute_user(
    body: ApiUnmuteUserRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public unmute user in a topic (publicUnmuteUser)

    Unmute user.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/unmute

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiUnmuteUserRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnmuteUser.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUnmuteUser)
async def public_unmute_user_async(
    body: ApiUnmuteUserRequest,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public unmute user in a topic (publicUnmuteUser)

    Unmute user.

    Properties:
        url: /chat/public/namespaces/{namespace}/topic/{topic}/unmute

        method: PUT

        tags: ["topic"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiUnmuteUserRequest in body

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnmuteUser.create(
        body=body,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum


class ScopeEnum(StrEnum):
    NAMESPACE = "NAMESPACE"
    USER = "USER"


class StatusEnum(StrEnum):
    DRAFT = "DRAFT"
    SENT = "SENT"
    UNSENT = "UNSENT"


class ModelsSaveInboxMessageResponse(Model):
    """Models save inbox message response (models.SaveInboxMessageResponse)

    Properties:
        expired_at: (expiredAt) REQUIRED int

        id_: (id) REQUIRED str

        scope: (scope) REQUIRED Union[str, ScopeEnum]

        status: (status) REQUIRED Union[str, StatusEnum]

        category: (category) OPTIONAL str

        message: (message) OPTIONAL Dict[str, Any]

        user_i_ds: (userIDs) OPTIONAL List[str]
    """

    # region fields

    expired_at: int  # REQUIRED
    id_: str  # REQUIRED
    scope: Union[str, ScopeEnum]  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    category: str  # OPTIONAL
    message: Dict[str, Any]  # OPTIONAL
    user_i_ds: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_expired_at(self, value: int) -> ModelsSaveInboxMessageResponse:
        self.expired_at = value
        return self

    def with_id(self, value: str) -> ModelsSaveInboxMessageResponse:
        self.id_ = value
        return self

    def with_scope(
        self, value: Union[str, ScopeEnum]
    ) -> ModelsSaveInboxMessageResponse:
        self.scope = value
        return self

    def with_status(
        self, value: Union[str, StatusEnum]
    ) -> ModelsSaveInboxMessageResponse:
        self.status = value
        return self

    def with_category(self, value: str) -> ModelsSaveInboxMessageResponse:
        self.category = value
        return self

    def with_message(self, value: Dict[str, Any]) -> ModelsSaveInboxMessageResponse:
        self.message = value
        return self

    def with_user_i_ds(self, value: List[str]) -> ModelsSaveInboxMessageResponse:
        self.user_i_ds = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "expired_at"):
            result["expiredAt"] = int(self.expired_at)
        elif include_empty:
            result["expiredAt"] = 0
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "scope"):
            result["scope"] = str(self.scope)
        elif include_empty:
            result["scope"] = Union[str, ScopeEnum]()
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "category"):
            result["category"] = str(self.category)
        elif include_empty:
            result["category"] = ""
        if hasattr(self, "message"):
            result["message"] = {str(k0): v0 for k0, v0 in self.message.items()}
        elif include_empty:
            result["message"] = {}
        if hasattr(self, "user_i_ds"):
            result["userIDs"] = [str(i0) for i0 in self.user_i_ds]
        elif include_empty:
            result["userIDs"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        expired_at: int,
        id_: str,
        scope: Union[str, ScopeEnum],
        status: Union[str, StatusEnum],
        category: Optional[str] = None,
        message: Optional[Dict[str, Any]] = None,
        user_i_ds: Optional[List[str]] = None,
        **kwargs,
    ) -> ModelsSaveInboxMessageResponse:
        instance = cls()
        instance.expired_at = expired_at
        instance.id_ = id_
        instance.scope = scope
        instance.status = status
        if category is not None:
            instance.category = category
        if message is not None:
            instance.message = message
        if user_i_ds is not None:
            instance.user_i_ds = user_i_ds
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsSaveInboxMessageResponse:
        instance = cls()
        if not dict_:
            return instance
        if "expiredAt" in dict_ and dict_["expiredAt"] is not None:
            instance.expired_at = int(dict_["expiredAt"])
        elif include_empty:
            instance.expired_at = 0
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "scope" in dict_ and dict_["scope"] is not None:
            instance.scope = str(dict_["scope"])
        elif include_empty:
            instance.scope = Union[str, ScopeEnum]()
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "category" in dict_ and dict_["category"] is not None:
            instance.category = str(dict_["category"])
        elif include_empty:
            instance.category = ""
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = {str(k0): v0 for k0, v0 in dict_["message"].items()}
        elif include_empty:
            instance.message = {}
        if "userIDs" in dict_ and dict_["userIDs"] is not None:
            instance.user_i_ds = [str(i0) for i0 in dict_["userIDs"]]
        elif include_empty:
            instance.user_i_ds = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsSaveInboxMessageResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsSaveInboxMessageResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsSaveInboxMessageResponse,
        List[ModelsSaveInboxMessageResponse],
        Dict[Any, ModelsSaveInboxMessageResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "expiredAt": "expired_at",
            "id": "id_",
            "scope": "scope",
            "status": "status",
            "category": "category",
            "message": "message",
            "userIDs": "user_i_ds",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "expiredAt": True,
            "id": True,
            "scope": True,
            "status": True,
            "category": False,
            "message": False,
            "userIDs": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "scope": ["NAMESPACE", "USER"],
            "status": ["DRAFT", "SENT", "UNSENT"],
        }

    # endregion static methods
